==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/IdMatrixData.java <==
package com.example.model;

/**
 * Model for IdMatrix
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.328Z")
@io.swagger.annotations.ApiModel(value = "IdMatrixData", description = "Model for IdMatrix")
@javax.xml.bind.annotation.XmlRootElement(name = "IdMatrixData")
public class IdMatrixData implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private com.example.model.FraudAssessment fraudAssessment = null;
	private java.lang.String overall = null;
	private com.example.model.IdMatrixResults searchResults = null;
	private java.util.List<com.example.model.Summary> summary = null;
	
	/**
	 * Model for FraudAssessment
	 */
	public IdMatrixData fraudAssessment(com.example.model.FraudAssessment fraudAssessment) {
		setFraudAssessment(fraudAssessment);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "Model for FraudAssessment")
	@com.fasterxml.jackson.annotation.JsonProperty("fraudAssessment")
	@javax.validation.Valid
	@javax.validation.constraints.NotNull
	public com.example.model.FraudAssessment getFraudAssessment() {
		return this.fraudAssessment;
	}
	public void setFraudAssessment(com.example.model.FraudAssessment fraudAssessment) {
		this.fraudAssessment = fraudAssessment;
	}
	
	/**
	 */
	public IdMatrixData overall(java.lang.String overall) {
		setOverall(overall);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("overall")
	public java.lang.String getOverall() {
		return this.overall;
	}
	public void setOverall(java.lang.String overall) {
		this.overall = overall;
	}
	
	/**
	 * Model for SearchResults
	 */
	public IdMatrixData searchResults(com.example.model.IdMatrixResults searchResults) {
		setSearchResults(searchResults);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "Model for SearchResults")
	@com.fasterxml.jackson.annotation.JsonProperty("searchResults")
	@javax.validation.Valid
	public com.example.model.IdMatrixResults getSearchResults() {
		return this.searchResults;
	}
	public void setSearchResults(com.example.model.IdMatrixResults searchResults) {
		this.searchResults = searchResults;
	}
	
	/**
	 */
	public IdMatrixData summary(java.util.List<com.example.model.Summary> summary) {
		setSummary(summary);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("summary")
	@javax.validation.Valid
	public java.util.List<com.example.model.Summary> getSummary() {
		return this.summary;
	}
	public void setSummary(java.util.List<com.example.model.Summary> summary) {
		this.summary = summary;
	}
	public IdMatrixData addSummary(com.example.model.Summary summary) {
		if (this.summary == null) {
			this.summary = new java.util.ArrayList<com.example.model.Summary>();
		}
		this.summary.add(summary);
		return this;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		IdMatrixData idMatrixData = (IdMatrixData) o;
		return java.util.Objects.equals(this.fraudAssessment, idMatrixData.fraudAssessment)
				&& java.util.Objects.equals(this.overall, idMatrixData.overall)
				&& java.util.Objects.equals(this.searchResults, idMatrixData.searchResults)
				&& java.util.Objects.equals(this.summary, idMatrixData.summary);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.fraudAssessment, this.overall, this.searchResults, this.summary);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class IdMatrixData {\n");
		
		sb.append("    fraudAssessment: ").append(toIndentedString(this.fraudAssessment)).append("\n");
		sb.append("    overall: ").append(toIndentedString(this.overall)).append("\n");
		sb.append("    searchResults: ").append(toIndentedString(this.searchResults)).append("\n");
		sb.append("    summary: ").append(toIndentedString(this.summary)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/IdMatrixData.java <==
package com.example.model;

/**
 * Model for IdMatrix
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.431Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "IdMatrixData", description = "Model for IdMatrix")
@javax.xml.bind.annotation.XmlRootElement(name = "IdMatrixData")
public class IdMatrixData implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private com.example.model.FraudAssessment fraudAssessment = null;
	private java.lang.String overall = null;
	private com.example.model.IdMatrixResults searchResults = null;
	private java.util.List<com.example.model.Summary> summary = null;
	
	/**
	 * Model for FraudAssessment
	 */
	public IdMatrixData fraudAssessment(com.example.model.FraudAssessment fraudAssessment) {
		setFraudAssessment(fraudAssessment);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "fraudAssessment", description = "Model for FraudAssessment")
	@com.fasterxml.jackson.annotation.JsonProperty("fraudAssessment")
	@javax.validation.Valid
	@javax.validation.constraints.NotNull
	public com.example.model.FraudAssessment getFraudAssessment() {
		return this.fraudAssessment;
	}
	public void setFraudAssessment(com.example.model.FraudAssessment fraudAssessment) {
		this.fraudAssessment = fraudAssessment;
	}
	
	/**
	 */
	public IdMatrixData overall(java.lang.String overall) {
		setOverall(overall);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "overall")
	@com.fasterxml.jackson.annotation.JsonProperty("overall")
	public java.lang.String getOverall() {
		return this.overall;
	}
	public void setOverall(java.lang.String overall) {
		this.overall = overall;
	}
	
	/**
	 * Model for SearchResults
	 */
	public IdMatrixData searchResults(com.example.model.IdMatrixResults searchResults) {
		setSearchResults(searchResults);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "searchResults", description = "Model for SearchResults")
	@com.fasterxml.jackson.annotation.JsonProperty("searchResults")
	@javax.validation.Valid
	public com.example.model.IdMatrixResults getSearchResults() {
		return this.searchResults;
	}
	public void setSearchResults(com.example.model.IdMatrixResults searchResults) {
		this.searchResults = searchResults;
	}
	
	/**
	 */
	public IdMatrixData summary(java.util.List<com.example.model.Summary> summary) {
		setSummary(summary);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "summary")
	@com.fasterxml.jackson.annotation.JsonProperty("summary")
	@javax.validation.Valid
	public java.util.List<com.example.model.Summary> getSummary() {
		return this.summary;
	}
	public void setSummary(java.util.List<com.example.model.Summary> summary) {
		this.summary = summary;
	}
	public IdMatrixData addSummary(com.example.model.Summary summary) {
		if (this.summary == null) {
			this.summary = new java.util.ArrayList<com.example.model.Summary>();
		}
		this.summary.add(summary);
		return this;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		IdMatrixData idMatrixData = (IdMatrixData) o;
		return java.util.Objects.equals(this.fraudAssessment, idMatrixData.fraudAssessment)
				&& java.util.Objects.equals(this.overall, idMatrixData.overall)
				&& java.util.Objects.equals(this.searchResults, idMatrixData.searchResults)
				&& java.util.Objects.equals(this.summary, idMatrixData.summary);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.fraudAssessment, this.overall, this.searchResults, this.summary);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class IdMatrixData {\n");
		
		sb.append("    fraudAssessment: ").append(toIndentedString(this.fraudAssessment)).append("\n");
		sb.append("    overall: ").append(toIndentedString(this.overall)).append("\n");
		sb.append("    searchResults: ").append(toIndentedString(this.searchResults)).append("\n");
		sb.append("    summary: ").append(toIndentedString(this.summary)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
